From c7fbe94bf4ca0285d9af2a090d085f785e466026 Mon Sep 17 00:00:00 2001
From: EndrII <EndrIIMail@gmail.com>
Date: Fri, 28 Jul 2023 09:56:50 +0200
Subject: [PATCH] rename project

---
 .gitmodules                                   |  3 +++
 CMakeLists.txt                                | 20 +++++++++----------
 README.md                                     |  2 +-
 doxygen.conf.in                               |  8 ++++----
 init.sh                                       |  8 ++++----
 src/Example/CMakeLists.txt                    | 16 +++++++--------
 ...AME_ME.json.in => ButterflyEngine.json.in} |  6 +++---
 src/Example/android/AndroidManifest.xml.in    |  2 +-
 src/Library/ButterflyEngine.qrc               |  9 +++++++++
 src/Library/CMakeLists.txt                    |  4 ++--
 src/Library/RENAME_ME.qrc                     |  9 ---------
 .../ButterflyEngine.qml}                      |  0
 src/Library/src/ButterflyEngineModule/qmldir  |  3 +++
 src/Library/src/RENAME_MEModule/qmldir        |  3 ---
 .../{RENAME_ME.cpp => ButterflyEngine.cpp}    |  8 ++++----
 .../public/{RENAME_ME.h => ButterflyEngine.h} | 12 +++++------
 .../global.h.in                               | 14 ++++++-------
 submodules/CMake                              |  1 +
 tests/tstMain.cpp                             |  2 +-
 19 files changed, 67 insertions(+), 63 deletions(-)
 rename src/Example/Deploy/{RENAME_ME.json.in => ButterflyEngine.json.in} (74%)
 create mode 100644 src/Library/ButterflyEngine.qrc
 delete mode 100644 src/Library/RENAME_ME.qrc
 rename src/Library/src/{RENAME_MEModule/RENAME_ME.qml => ButterflyEngineModule/ButterflyEngine.qml} (100%)
 create mode 100644 src/Library/src/ButterflyEngineModule/qmldir
 delete mode 100644 src/Library/src/RENAME_MEModule/qmldir
 rename src/Library/src/public/{RENAME_ME.cpp => ButterflyEngine.cpp} (70%)
 rename src/Library/src/public/{RENAME_ME.h => ButterflyEngine.h} (60%)
 rename src/Library/src/public/{RENAME_ME => ButterflyEngine}/global.h.in (50%)
 create mode 160000 submodules/CMake

diff --git a/.gitmodules b/.gitmodules
index f305b28..8b95c0b 100644
--- a/.gitmodules
+++ b/.gitmodules
@@ -1,3 +1,6 @@
 [submodule "CMake"]
 	path = submodules/CMake
 	url = https://github.com/QuasarApp/CMake.git
+[submodule "submodules/CMake"]
+	path = submodules/CMake
+	url = https://github.com/QuasarApp/CMake.git
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 4162994..f65151f 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -6,7 +6,7 @@
 #
 
 cmake_minimum_required(VERSION 3.18)
-project(RENAME_ME LANGUAGES CXX)
+project(ButterflyEngine LANGUAGES CXX)
 if(TARGET ${PROJECT_NAME})
   message("The ${PROJECT_NAME} arledy included in main Project")
   return()
@@ -32,18 +32,18 @@ find_package(Qt${QT_VERSION_MAJOR} COMPONENTS Core Test QUIET)
 include(submodules/CMake/QuasarApp.cmake)
 
 updateGitVars()
-set(RENAME_ME_VERSION "0.${GIT_COMMIT_COUNT}.${GIT_COMMIT_HASH}")
-set(RENAME_ME_PACKAGE_ID "quasarapp.core.RENAME_ME")
+set(ButterflyEngine_VERSION "0.${GIT_COMMIT_COUNT}.${GIT_COMMIT_HASH}")
+set(ButterflyEngine_PACKAGE_ID "quasarapp.core.ButterflyEngine")
 
-option(RENAME_ME_TESTS "This option disables or enables tests of the ${PROJECT_NAME} project"  ON)
-option(RENAME_ME_EXAMPLE "This option disables or enables example app of the ${PROJECT_NAME} project" ON)
+option(ButterflyEngine_TESTS "This option disables or enables tests of the ${PROJECT_NAME} project"  ON)
+option(ButterflyEngine_EXAMPLE "This option disables or enables example app of the ${PROJECT_NAME} project" ON)
 
 if (ANDROID OR IOS OR NOT QT_VERSION_MAJOR OR QA_WASM32)
-    set(RENAME_ME_TESTS OFF CACHE BOOL "This option force disbled for ANDROID IOS QA_WASM32 and Not Qt projects" FORCE)
+    set(ButterflyEngine_TESTS OFF CACHE BOOL "This option force disbled for ANDROID IOS QA_WASM32 and Not Qt projects" FORCE)
 endif()
 
 if (NOT QT_VERSION_MAJOR)
-    set(RENAME_ME_EXAMPLE OFF CACHE BOOL "This option force disbled for Not Qt projects" FORCE)
+    set(ButterflyEngine_EXAMPLE OFF CACHE BOOL "This option force disbled for Not Qt projects" FORCE)
 endif()
 
 make_directory(Distro)
@@ -52,11 +52,11 @@ initAll()
 
 add_subdirectory(src/Library)
 
-if (DEFINED RENAME_ME_EXAMPLE)
+if (DEFINED ButterflyEngine_EXAMPLE)
     add_subdirectory(src/Example)
 endif()
 
-if (RENAME_ME_TESTS)
+if (ButterflyEngine_TESTS)
     add_subdirectory(tests)
 else()
     message("The ${PROJECT_NAME} tests is disabled.")
@@ -64,4 +64,4 @@ endif()
 
 configure_file_in(${PROJECT_NAME} ${CMAKE_CURRENT_SOURCE_DIR}/doxygen.conf)
 addDoc(${PROJECT_NAME} ${CMAKE_CURRENT_SOURCE_DIR}/doxygen.conf)
-addDeployFromCustomFile("RENAME_ME" "${CMAKE_CURRENT_SOURCE_DIR}/Deploy/RENAME_ME.json")
+addDeployFromCustomFile("ButterflyEngine" "${CMAKE_CURRENT_SOURCE_DIR}/Deploy/ButterflyEngine.json")
diff --git a/README.md b/README.md
index 0a44cbb..0c2c623 100644
--- a/README.md
+++ b/README.md
@@ -1,6 +1,6 @@
 # CMakeProject
 Template repository for cmake project
-Fork me and replase RENAME_ME to Name of your new project.
+Fork me and replase ButterflyEngine to Name of your new project.
 
 1. Clone this repository 
 2. Run ./init.sh NewProjectName 
diff --git a/doxygen.conf.in b/doxygen.conf.in
index 5857193..c5ef3af 100644
--- a/doxygen.conf.in
+++ b/doxygen.conf.in
@@ -32,18 +32,18 @@ DOXYFILE_ENCODING      = UTF-8
 # title of most generated pages and in a few other places.
 # The default value is: My Project.
 
-PROJECT_NAME           = RENAME_ME
+PROJECT_NAME           = ButterflyEngine
 # The PROJECT_NUMBER tag can be used to enter a project or revision number. This
 # could be handy for archiving the generated documentation or if some version
 # control system is used.
 
-PROJECT_NUMBER         = @RENAME_ME_VERSION@
+PROJECT_NUMBER         = @ButterflyEngine_VERSION@
 
 # Using the PROJECT_BRIEF tag one can provide an optional one line description
 # for a project that appears at the top of each page and should give viewer a
 # quick idea about the purpose of the project. Keep the description short.
 
-PROJECT_BRIEF          = RENAME_ME is base back end library for your c++ Qt projects.
+PROJECT_BRIEF          = ButterflyEngine is base back end library for your c++ Qt projects.
 
 
 # With the PROJECT_LOGO tag one can specify a logo or an icon that is included
@@ -1452,7 +1452,7 @@ GENERATE_ECLIPSEHELP   = NO
 # The default value is: org.doxygen.Project.
 # This tag requires that the tag GENERATE_ECLIPSEHELP is set to YES.
 
-ECLIPSE_DOC_ID         = QuasarApp.RENAME_ME
+ECLIPSE_DOC_ID         = QuasarApp.ButterflyEngine
 
 # If you want full control over the layout of the generated HTML pages it might
 # be necessary to disable the index and replace it with your own. The
diff --git a/init.sh b/init.sh
index 4ab4efd..df6fb86 100755
--- a/init.sh
+++ b/init.sh
@@ -10,16 +10,16 @@ then
     exit 1
 fi
 
-REPLACESTRING="s+RENAME_ME+$1+g"
+REPLACESTRING="s+ButterflyEngine+$1+g"
 echo $REPLACESTRING
 
 find . -not -path '*/\.*' -type f -exec sed -i $REPLACESTRING {} +
 find . -not -path '*/\.*' -type f -exec sed -i $REPLACESTRING {} +
 
-find src -type d -name '*RENAME_ME*' -exec sh -c 'x="{}"; NEWSTR=$(echo "$x" | sed "s/RENAME_ME/'$1'/"); mv "$x" "$NEWSTR"' \;
+find src -type d -name '*ButterflyEngine*' -exec sh -c 'x="{}"; NEWSTR=$(echo "$x" | sed "s/ButterflyEngine/'$1'/"); mv "$x" "$NEWSTR"' \;
 
-find src -type f -name '*RENAME_ME*' -exec sh -c 'x="{}"; NEWSTR=$(echo "$x" | sed "s/RENAME_ME/'$1'/"); mv "$x" "$NEWSTR"' \;
-find Deploy -type f -name '*RENAME_ME*' -exec sh -c 'x="{}"; NEWSTR=$(echo "$x" | sed "s/RENAME_ME/'$1'/"); mv "$x" "$NEWSTR"' \;
+find src -type f -name '*ButterflyEngine*' -exec sh -c 'x="{}"; NEWSTR=$(echo "$x" | sed "s/ButterflyEngine/'$1'/"); mv "$x" "$NEWSTR"' \;
+find Deploy -type f -name '*ButterflyEngine*' -exec sh -c 'x="{}"; NEWSTR=$(echo "$x" | sed "s/ButterflyEngine/'$1'/"); mv "$x" "$NEWSTR"' \;
 
 set -e
 
diff --git a/src/Example/CMakeLists.txt b/src/Example/CMakeLists.txt
index 4e0b51e..a42005b 100644
--- a/src/Example/CMakeLists.txt
+++ b/src/Example/CMakeLists.txt
@@ -58,7 +58,7 @@ if (ANDROID)
     set(ANDROID_API_VERSION $ENV{ANDROID_API_VERSION})
     set(OPENSSL_ROOT_PATH "$ENV{OPENSSL_ROOT_DIR}")
 
-    set(RENAME_ME_EXTRA_LIBS
+    set(ButterflyEngine_EXTRA_LIBS
         ${PROJECT_NAME}Library
 #        libName
         )
@@ -74,7 +74,7 @@ if (ANDROID)
             "${SIGPATH}/quasarapp.keystore"
             "${SIGPASS_QUASARAPP}"
             "${TARGET_DIR}"
-            "${RENAME_ME_EXTRA_LIBS}")
+            "${ButterflyEngine_EXTRA_LIBS}")
 
     else()
         message("NO_SIGN_APP")
@@ -82,7 +82,7 @@ if (ANDROID)
         addDeployAPK(${CURRENT_PROJECT}
             "${CMAKE_CURRENT_LIST_DIR}/android"
             "${TARGET_DIR}"
-            "${RENAME_ME_EXTRA_LIBS}")
+            "${ButterflyEngine_EXTRA_LIBS}")
 
     endif()
     set(manifest_file "${CMAKE_CURRENT_SOURCE_DIR}/android/AndroidManifest.xml")
@@ -108,19 +108,19 @@ elseif(IOS)
 #    set_xcode_property(${CURRENT_PROJECT} PRODUCT_BUNDLE_IDENTIFIER ${CHEATCARD_PACKAGE_ID} All)
 
     set_target_properties(${CURRENT_PROJECT} PROPERTIES
-        MACOSX_BUNDLE_GUI_IDENTIFIER ${RENAME_ME_PACKAGE_ID}
-        MACOSX_BUNDLE_BUNDLE_VERSION ${RENAME_ME_VERSION}
-        MACOSX_BUNDLE_SHORT_VERSION_STRING ${RENAME_ME_VERSION}
+        MACOSX_BUNDLE_GUI_IDENTIFIER ${ButterflyEngine_PACKAGE_ID}
+        MACOSX_BUNDLE_BUNDLE_VERSION ${ButterflyEngine_VERSION}
+        MACOSX_BUNDLE_SHORT_VERSION_STRING ${ButterflyEngine_VERSION}
     )
 else()
     # Desctop deploying
 
     message(GIT_COMMIT_COUNT = ${GIT_COMMIT_COUNT})
 
-    set(DeployFile "${CMAKE_CURRENT_SOURCE_DIR}/Deploy/RENAME_ME.json")
+    set(DeployFile "${CMAKE_CURRENT_SOURCE_DIR}/Deploy/ButterflyEngine.json")
     configure_file("${DeployFile}.in" ${DeployFile} @ONLY)
 
-    addDeployFromCustomFile("RENAME_ME" ${DeployFile})
+    addDeployFromCustomFile("ButterflyEngine" ${DeployFile})
 
 endif()
 
diff --git a/src/Example/Deploy/RENAME_ME.json.in b/src/Example/Deploy/ButterflyEngine.json.in
similarity index 74%
rename from src/Example/Deploy/RENAME_ME.json.in
rename to src/Example/Deploy/ButterflyEngine.json.in
index 45063d4..a7f1b90 100644
--- a/src/Example/Deploy/RENAME_ME.json.in
+++ b/src/Example/Deploy/ButterflyEngine.json.in
@@ -1,7 +1,7 @@
 {
     "bin": [
-        "src/build/Debug/RENAME_MEEaxample",
-        "src/build/Debug/RENAME_MEEaxample.exe"
+        "src/build/Debug/ButterflyEngineEaxample",
+        "src/build/Debug/ButterflyEngineEaxample.exe"
         ],
     "clear": true,
     "binPrefix": "@CMAKE_BINARY_DIR@",
@@ -21,7 +21,7 @@
         ],
     "extraLib": "crypto",
     "targetDir": "@CMAKE_SOURCE_DIR@/Distro",
-    "deployVersion": "@RENAME_ME_VERSION@",
+    "deployVersion": "@ButterflyEngine_VERSION@",
 
 }
 
diff --git a/src/Example/android/AndroidManifest.xml.in b/src/Example/android/AndroidManifest.xml.in
index 7f7beef..e7c9b68 100644
--- a/src/Example/android/AndroidManifest.xml.in
+++ b/src/Example/android/AndroidManifest.xml.in
@@ -1,5 +1,5 @@
 <?xml version="1.0"?>
-<manifest package="@RENAME_ME_PACKAGE_ID@" xmlns:android="http://schemas.android.com/apk/res/android" android:versionName="@RENAME_ME_VERSION@" android:versionCode="@GIT_COMMIT_COUNT@" android:installLocation="auto">
+<manifest package="@ButterflyEngine_PACKAGE_ID@" xmlns:android="http://schemas.android.com/apk/res/android" android:versionName="@ButterflyEngine_VERSION@" android:versionCode="@GIT_COMMIT_COUNT@" android:installLocation="auto">
     <!-- The following comment will be replaced upon deployment with default permissions based on the dependencies of the application.
          Remove the comment if you do not require these default permissions. -->
     <!-- %%INSERT_PERMISSIONS -->
diff --git a/src/Library/ButterflyEngine.qrc b/src/Library/ButterflyEngine.qrc
new file mode 100644
index 0000000..b504866
--- /dev/null
+++ b/src/Library/ButterflyEngine.qrc
@@ -0,0 +1,9 @@
+<RCC>
+    <qresource prefix="/">
+        <file>src/ButterflyEngineModule/qmldir</file>
+        <file>src/ButterflyEngineModule/ButterflyEngine.qml</file>
+    </qresource>
+    <qresource prefix="/ButterflyEngineTr">
+        <file>languages/en.qm</file>
+    </qresource>
+</RCC>
diff --git a/src/Library/CMakeLists.txt b/src/Library/CMakeLists.txt
index 9c84273..841391c 100644
--- a/src/Library/CMakeLists.txt
+++ b/src/Library/CMakeLists.txt
@@ -10,7 +10,7 @@ cmake_minimum_required(VERSION 3.18)
 get_filename_component(CURRENT_PROJECT_DIR ${CMAKE_CURRENT_SOURCE_DIR} NAME)
 
 set(CURRENT_PROJECT "${PROJECT_NAME}${CURRENT_PROJECT_DIR}")
-add_definitions(-DRENAME_ME_LIBRARY)
+add_definitions(-DButterflyEngine_LIBRARY)
 
 
 file(GLOB_RECURSE SOURCE_CPP
@@ -45,5 +45,5 @@ prepareQM(${CURRENT_PROJECT} ${CMAKE_CURRENT_SOURCE_DIR} "${LANGS}")
 
 set(QML_IMPORT_PATH ${QML_IMPORT_PATH} "${CMAKE_CURRENT_SOURCE_DIR}/src" CACHE STRING "" FORCE)
 
-set(global_file "${CMAKE_CURRENT_SOURCE_DIR}/src/public/RENAME_ME/global.h")
+set(global_file "${CMAKE_CURRENT_SOURCE_DIR}/src/public/ButterflyEngine/global.h")
 configure_file("${global_file}.in" ${global_file} @ONLY)
diff --git a/src/Library/RENAME_ME.qrc b/src/Library/RENAME_ME.qrc
deleted file mode 100644
index c6c3d8e..0000000
--- a/src/Library/RENAME_ME.qrc
+++ /dev/null
@@ -1,9 +0,0 @@
-<RCC>
-    <qresource prefix="/">
-        <file>src/RENAME_MEModule/qmldir</file>
-        <file>src/RENAME_MEModule/RENAME_ME.qml</file>
-    </qresource>
-    <qresource prefix="/RENAME_METr">
-        <file>languages/en.qm</file>
-    </qresource>
-</RCC>
diff --git a/src/Library/src/RENAME_MEModule/RENAME_ME.qml b/src/Library/src/ButterflyEngineModule/ButterflyEngine.qml
similarity index 100%
rename from src/Library/src/RENAME_MEModule/RENAME_ME.qml
rename to src/Library/src/ButterflyEngineModule/ButterflyEngine.qml
diff --git a/src/Library/src/ButterflyEngineModule/qmldir b/src/Library/src/ButterflyEngineModule/qmldir
new file mode 100644
index 0000000..d4358fe
--- /dev/null
+++ b/src/Library/src/ButterflyEngineModule/qmldir
@@ -0,0 +1,3 @@
+module ButterflyEngineModule
+ButterflyEngine 1.0 ButterflyEngine.qml
+
diff --git a/src/Library/src/RENAME_MEModule/qmldir b/src/Library/src/RENAME_MEModule/qmldir
deleted file mode 100644
index 966edab..0000000
--- a/src/Library/src/RENAME_MEModule/qmldir
+++ /dev/null
@@ -1,3 +0,0 @@
-module RENAME_MEModule
-RENAME_ME 1.0 RENAME_ME.qml
-
diff --git a/src/Library/src/public/RENAME_ME.cpp b/src/Library/src/public/ButterflyEngine.cpp
similarity index 70%
rename from src/Library/src/public/RENAME_ME.cpp
rename to src/Library/src/public/ButterflyEngine.cpp
index f18b899..b769f49 100644
--- a/src/Library/src/public/RENAME_ME.cpp
+++ b/src/Library/src/public/ButterflyEngine.cpp
@@ -5,18 +5,18 @@
 //# of this license document, but changing it is not allowed.
 //#
 
-#include "RENAME_ME.h"
+#include "ButterflyEngine.h"
 
 
-namespace RENAME_ME {
+namespace ButterflyEngine {
 
 bool init() {
-    initRENAME_MEResources();
+    initButterflyEngineResources();
     return true;
 }
 
 QString version() {
-    return RENAME_ME_VERSION;
+    return ButterflyEngine_VERSION;
 }
 
 
diff --git a/src/Library/src/public/RENAME_ME/global.h.in b/src/Library/src/public/ButterflyEngine/global.h.in
similarity index 50%
rename from src/Library/src/public/RENAME_ME/global.h.in
rename to src/Library/src/public/ButterflyEngine/global.h.in
index 312004f..30b265a 100644
--- a/src/Library/src/public/RENAME_ME/global.h.in
+++ b/src/Library/src/public/ButterflyEngine/global.h.in
@@ -5,18 +5,18 @@
 //# of this license document, but changing it is not allowed.
 //#
 
-#ifndef RENAME_ME_GLOBAL_H
-#define RENAME_ME_GLOBAL_H
+#ifndef ButterflyEngine_GLOBAL_H
+#define ButterflyEngine_GLOBAL_H
 
 #include <QtCore/qglobal.h>
 
-#define RENAME_ME_VERSION "@RENAME_ME_VERSION@"
+#define ButterflyEngine_VERSION "@ButterflyEngine_VERSION@"
 
-#if defined(RENAME_ME_LIBRARY)
-#  define RENAME_ME_EXPORT Q_DECL_EXPORT
+#if defined(ButterflyEngine_LIBRARY)
+#  define ButterflyEngine_EXPORT Q_DECL_EXPORT
 #else
-#  define RENAME_ME_EXPORT Q_DECL_IMPORT
+#  define ButterflyEngine_EXPORT Q_DECL_IMPORT
 #endif
 
-#endif //RENAME_ME_GLOBAL_H
+#endif //ButterflyEngine_GLOBAL_H
 
diff --git a/submodules/CMake b/submodules/CMake
new file mode 160000
index 0000000..3b89e31
--- /dev/null
+++ b/submodules/CMake
@@ -0,0 +1 @@
+Subproject commit 3b89e311c350868cead4bf2a36fd557989716043
diff --git a/tests/tstMain.cpp b/tests/tstMain.cpp
index 3beb3ee..06c1bc7 100644
--- a/tests/tstMain.cpp
+++ b/tests/tstMain.cpp
@@ -57,7 +57,7 @@ tstMain::tstMain() {
     char * argv[] = {nullptr};
 
     _app = new QCoreApplication(argc, argv);
-    QCoreApplication::setApplicationName("testRENAME_ME");
+    QCoreApplication::setApplicationName("testButterflyEngine");
     QCoreApplication::setOrganizationName("QuasarApp");
 
     auto path = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
diff --git a/src/Library/src/public/RENAME_ME.h b/src/Library/src/public/ButterflyEngine.h
similarity index 60%
rename from src/Library/src/public/RENAME_ME.h
rename to src/Library/src/public/ButterflyEngine.h
index bee7dbf..52f09e1 100644
--- a/src/Library/src/public/RENAME_ME.h
+++ b/src/Library/src/public/ButterflyEngine.h
@@ -5,23 +5,23 @@
 //# of this license document, but changing it is not allowed.
 //#
 
-#include "RENAME_ME/global.h"
+#include "ButterflyEngine/global.h"
 #include <QString>
 
-inline void initRENAME_MEResources() { Q_INIT_RESOURCE(RENAME_ME); }
+inline void initButterflyEngineResources() { Q_INIT_RESOURCE(ButterflyEngine); }
 
-namespace RENAME_ME {
+namespace ButterflyEngine {
 
 /**
  * @brief init main initialize method of The RENAME_ME library
  * @return true if library initialized successfull
  */
-bool RENAME_ME_EXPORT init();
+bool ButterflyEngine_EXPORT init();
 
 /**
  * @brief version This method return string value of a library version
  * @return string value of a library version
  */
-QString RENAME_ME_EXPORT version();
+QString ButterflyEngine_EXPORT version();
 
 };
@@ -5,23 +5,23 @@
 
 /**
- * @brief init main initialize method of The RENAME_ME library
+ * @brief init main initialize method of The ButterflyEngine library
  * @return true if library initialized successfull
  */